@@ -2,13 +2,13 @@
 """
 ..
     SmartHTTP 
-    Release 0.5 rev. 279 on 2010-07-20 04:32:27.374371
+    Release 0.5 rev. 289 on 2010-08-19 09:27:31.860316
     Copyright (C) 2009-2010,
     Authors: Dan Kluev <dan@kluev.name>
 
     Module smarthttp.lib
     Some additional libraries
-    Last changed on 2010-05-21 20:04:13+11:00 rev. 219:eb74038dbda0 by Dan Kluev <orion@ssorion.info>
+    Last changed on 2010-07-20 20:31:18+11:00 rev. 280:8c22a24582d0 by Dan Kluev <dan@kluev.name>
 
 ..
     This program is free software: you can redistribute it and/or modify
@@ -34,9 +34,6 @@ Some additional libraries
    smarthttp.lib.containers
 
 :mod:`smarthttp.lib.containers`
-:mod:`smarthttp.lib.simplebot`
-:mod:`smarthttp.lib.httpbot`
-:mod:`smarthttp.lib.pylonsscript`
 
 """
 
