@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 """
+..
     SmartHTTP 
-    Release 0.5 rev. 279 on 2010-07-20 04:32:27.374371
+    Release 0.5 rev. 289 on 2010-08-19 09:27:31.860316
     Copyright (C) 2009-2010,
     Authors: Dan Kluev <dan@kluev.name>
 
     Module smarthttp.sites.translators.infoseek
     Client for translation.infoseek.co.jp
-    Last changed on 2010-05-14 19:41:11+11:00 rev. 161:56808a81dfc1 by Dan Kluev <orion@ssorion.info>
+    Last changed on 2010-07-26 19:03:56+11:00 rev. 286:5bad0f3a5211 by Dan Kluev <dan@kluev.name>
 
+..
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -21,21 +23,37 @@
     
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+
+Client for translation.infoseek.co.jp
+=====================================
 """
-from smarthttp.sites.translators import *
+from . import *
 
 class Infoseek(SpecificSite):
+    u"""Site handler for Infoseek translator, which provides accurate Ja/En translations.
+    
+    >>> site = Infoseek()
+    >>> word = site.translate(word=u"水")
+    >>> word.data.translation
+    u'Water'
+    
+    """
     domain = 'translation.infoseek.co.jp'
+    map    = SmartMap([
+           ('translate', '/', dict()),
+           ])
+           
     def __init__(self, *t, **d):
         SpecificSite.__init__(self, *t, **d)
         self.token = None
 
     def prepare(self):
-        req = self.request('http://translation.infoseek.co.jp/')
-        self.get_token(req)
+        resp = self.load('translate')
+        self.get_token(resp)
 
-    def get_token(self, req):
-        token_input = req.dom.xpath("/html/body/div//input[@name='token']")[0] 
+    def get_token(self, resp):
+        token_input = resp.assertHTML().assertXPathOne("/html/body/div//input[@name='token']")
         self.token = token_input.get("value")
         
     def translate(self, word=None, from_l='ja', to_l='en'):
@@ -50,12 +68,12 @@ class Infoseek(SpecificSite):
         else:
             selector = '0'
         data = {'ac':'Text', 'lng':'en', 'original':word_enc, 'selector':selector, 'token':self.token, 'submit':'　翻訳'}
-        req = self.request('http://translation.infoseek.co.jp/', request="POST", data=data)
-        self.get_token(req)
-        document = req.dom
-        converted = document.xpath("/html/body/div//textarea[@name='converted']")[0]
+        resp = self.request(self.url('translate'), data=data)
+        self.get_token(resp)
+        doc = resp.assertHTML()
+        converted = doc.assertXPathOne("/html/body/div//textarea[@name='converted']")
         word = converted.text
         if type(word) == str:
             word = unicode(word, 'utf-8')
         self.log.debug("Word: %s, token: %s" % (word, self.token))
-        return self.ok(word)
+        return self.ok(SmartDict(translation=word))
